==> smart-wx-service-20.0.9-sources.jar: net/guerlab/smart/wx/service/service/impl/WxMaManagerServiceImpl.java <==
package net.guerlab.smart.wx.service.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.api.impl.WxMaServiceImpl;
import cn.binarywang.wx.miniapp.config.WxMaConfig;
import net.guerlab.smart.wx.core.enums.WxAppType;
import net.guerlab.smart.wx.core.exception.WxAppInvalidException;
import net.guerlab.smart.wx.miniapp.spring.storate.WxMiniAppRedisTemplateConfigStorage;
import net.guerlab.smart.wx.service.entity.WxApp;
import net.guerlab.smart.wx.service.service.AfterWxAppDeleteHandler;
import net.guerlab.smart.wx.service.service.AfterWxAppUpdateHandler;
import net.guerlab.smart.wx.service.service.WxAppService;
import net.guerlab.smart.wx.service.service.WxMaManagerService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

/**
 * 微信小程序服务管理实现
 *
 * @author guer
 */
@Service
public class WxMaManagerServiceImpl implements WxMaManagerService, AfterWxAppUpdateHandler, AfterWxAppDeleteHandler {

    private final Map<String, WxMaService> serviceMap = new ConcurrentHashMap<>(8);

    private final Lock initLock = new ReentrantLock();

    private WxAppService wxAppService;

    private RedisTemplate<String, String> redisTemplate;

    @Override
    public WxMaService getService(String appId) {
        appId = StringUtils.trimToNull(appId);
        if (appId == null) {
            return null;
        }

        WxMaService service = serviceMap.get(appId);

        if (service != null) {
            return service;
        }

        initLock.lock();
        try {
            WxMaConfig config = buildConfigStorage(appId);
            service = new WxMaServiceImpl();
            service.setWxMaConfig(config);

            serviceMap.put(appId, service);

            return service;
        } finally {
            initLock.unlock();
        }
    }

    private WxMaConfig buildConfigStorage(String appId) {
        WxApp wxApp = wxAppService.selectById(appId);
        if (wxApp == null || wxApp.getWxAppType() != WxAppType.MINI_APP) {
            throw new WxAppInvalidException();
        }

        WxMiniAppRedisTemplateConfigStorage storage = new WxMiniAppRedisTemplateConfigStorage(redisTemplate);
        storage.setAppid(wxApp.getAppId());
        storage.setSecret(wxApp.getSecret());
        storage.setToken(wxApp.getToken());
        storage.setAesKey(wxApp.getAesKey());
        storage.setMsgDataFormat(wxApp.getMsgDataFormat().toString());
        return storage;
    }

    @Override
    public void afterWxAppUpdateHandler(WxApp wxApp) {
        if (wxApp.getWxAppType() == WxAppType.MINI_APP) {
            afterWxAppDeleteHandler(wxApp.getAppId());
        }
    }

    @Override
    public void afterWxAppDeleteHandler(String appId) {
        initLock.lock();
        try {
            serviceMap.remove(appId);
        } finally {
            initLock.unlock();
        }
    }

    @Autowired
    public void setWxAppService(WxAppService wxAppService) {
        this.wxAppService = wxAppService;
    }

    @Autowired
    public void setRedisTemplate(RedisTemplate<String, String> redisTemplate) {
        this.redisTemplate = redisTemplate;
    }
}

==> smart-wx-service-20.1.3-sources.jar: net/guerlab/smart/wx/service/service/impl/WxMaManagerServiceImpl.java <==
package net.guerlab.smart.wx.service.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.api.impl.WxMaServiceImpl;
import cn.binarywang.wx.miniapp.config.WxMaConfig;
import net.guerlab.smart.wx.core.enums.WxAppType;
import net.guerlab.smart.wx.core.exception.WxAppInvalidException;
import net.guerlab.smart.wx.miniapp.spring.storate.WxMiniAppRedisTemplateConfigStorage;
import net.guerlab.smart.wx.service.entity.WxApp;
import net.guerlab.smart.wx.service.handler.AfterWxAppDeleteHandler;
import net.guerlab.smart.wx.service.handler.AfterWxAppUpdateHandler;
import net.guerlab.smart.wx.service.service.WxAppService;
import net.guerlab.smart.wx.service.service.WxMaManagerService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

/**
 * 微信小程序服务管理实现
 *
 * @author guer
 */
@Service
public class WxMaManagerServiceImpl implements WxMaManagerService, AfterWxAppUpdateHandler, AfterWxAppDeleteHandler {

    private final Map<String, WxMaService> serviceMap = new ConcurrentHashMap<>(8);

    private final Lock initLock = new ReentrantLock();

    private WxAppService wxAppService;

    private RedisTemplate<String, String> redisTemplate;

    @Override
    public WxMaService getService(String appId) {
        appId = StringUtils.trimToNull(appId);
        if (appId == null) {
            return null;
        }

        WxMaService service = serviceMap.get(appId);

        if (service != null) {
            return service;
        }

        initLock.lock();
        try {
            WxMaConfig config = buildConfigStorage(appId);
            service = new WxMaServiceImpl();
            service.setWxMaConfig(config);

            serviceMap.put(appId, service);

            return service;
        } finally {
            initLock.unlock();
        }
    }

    private WxMaConfig buildConfigStorage(String appId) {
        WxApp wxApp = wxAppService.selectById(appId);
        if (wxApp == null || wxApp.getWxAppType() != WxAppType.MINI_APP) {
            throw new WxAppInvalidException();
        }

        WxMiniAppRedisTemplateConfigStorage storage = new WxMiniAppRedisTemplateConfigStorage(redisTemplate);
        storage.setAppid(wxApp.getAppId());
        storage.setSecret(wxApp.getSecret());
        storage.setToken(wxApp.getToken());
        storage.setAesKey(wxApp.getAesKey());
        storage.setMsgDataFormat(wxApp.getMsgDataFormat().toString());
        return storage;
    }

    @Override
    public void afterWxAppUpdateHandler(WxApp wxApp) {
        if (wxApp.getWxAppType() == WxAppType.MINI_APP) {
            afterWxAppDeleteHandler(wxApp.getAppId());
        }
    }

    @Override
    public void afterWxAppDeleteHandler(String appId) {
        initLock.lock();
        try {
            serviceMap.remove(appId);
        } finally {
            initLock.unlock();
        }
    }

    @Autowired
    public void setWxAppService(WxAppService wxAppService) {
        this.wxAppService = wxAppService;
    }

    @Autowired
    public void setRedisTemplate(RedisTemplate<String, String> redisTemplate) {
        this.redisTemplate = redisTemplate;
    }
}
